@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000, 2001, 2002 Ed L. Cashin
+Copyright (C) 2005 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,23 +22,25 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 typedef enum ruleflag {
   /* prefix rules */
-  RULE_IGNORE		 = 0x01,
-  RULE_NOCHILDREN	 = 0x02,
-  RULE_NOINHERIT	 = 0x04, /* true if this file has a non-inheriting
+  RULE_IGNORE		= 0x01,
+  RULE_NOCHILDREN	= 0x02,
+  RULE_NOINHERIT	= 0x04, /* true if this file has a non-inheriting
 				  * checkset */
 
   /* suffix rules */
-  RULE_SUM		 = 0x04,
-  RULE_INODE		 = 0x08,
-  RULE_PERMS		 = 0x10,
-  RULE_NLINK		 = 0x20,
-  RULE_UID		 = 0x40,
-  RULE_GID		 = 0x80,
-  RULE_SIZE		 = 0x100,
-  RULE_ATIME		 = 0x200,
-  RULE_MTIME		 = 0x400,
-  RULE_CTIME		 = 0x800,
-  RULE_RESET_ATIME	 = 0x1000,
+  RULE_SUM		= 0x04,
+  RULE_INODE		= 0x08,
+  RULE_PERMS		= 0x10,
+  RULE_NLINK		= 0x20,
+  RULE_UID		= 0x40,
+  RULE_GID		= 0x80,
+  RULE_SIZE		= 0x100,
+  RULE_ATIME		= 0x200,
+  RULE_MTIME		= 0x400,
+  RULE_CTIME		= 0x800,
+  RULE_RESET_ATIME	= 0x1000,
+  RULE_TYPE		= 0x2000,
+  RULE_DEVICETYPE	= 0x4000,
 } ruleflag;
 
 #endif
